==> prd_backup_01_06_23.zip: prd/storage/framework/views/1db2f5df2afa7f6a54304136284c012e70a4663f.php <==

<?php $__env->startSection('content'); ?>
<style>
  table{
  /* margin: 0 auto; */
  clear: both;
  border-collapse: collapse;
  /* table-layout: fixed;  */
  word-wrap:break-word; 
  display: inline-table;
} 
button.search_button {
    size: 28px;
    width: 30px;
    height: 24px;
}
.d-flex.justify-content-center {
    margin-top: 15px;
}
  </style>
<head>
  <meta name="csrf-token" content="<?php echo e(csrf_token()); ?>">
</head>
<div class="breadcrumb-area">
  <div class="container-fluid">
    <nav aria-label="breadcrumb">
      <ol class="breadcrumb">
        <li class="breadcrumb-item"><a href="#">Activity</a></li>
        </li>
      </ol>
    </nav>
  </div>
</div>

<div class="container-fluid">
  <div class="row">
    <div class="col-12">
      <div class="product-list--area bg-boxshadow">
        <div class="row">
          <div class="col-lg-12">
            <div class="ibox">
              <div class="ibox-content">
              <?php echo e(Form::open(array('route' => ['aircraftview'], 'id' => 'myForm'))); ?>

                <table id="my_table3" class="display table table-stripped toggle-arrow-tiny dataTable no-footer" data-page-size="15">
                 
                    <thead>
                      <tr>
                    <th>
                    <?php $entries = [800,50,10,25,100,200,300,500,900,1200]; ?>
                          <p>Show
                          <select name="no_of_entries" onchange="filtreresult()" id="no_of_entries">
                            <?php $__currentLoopData = $entries; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $entrie): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                              <?php if(isset($request['no_of_entries'])): ?>
                                <?php if($request['no_of_entries'] == $entrie): ?> 
                                  <option value='<?php echo $entrie; ?>' selected><?php echo $entrie; ?></option>
                                <?php else: ?>
                                  <option value='<?php echo $entrie; ?>'><?php echo $entrie; ?></option>
                                <?php endif; ?>  
                              <?php else: ?>
                              <option value="<?php echo $entrie; ?>"> <?php echo $entrie; ?></option>
                              <?php endif; ?>
                            <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                          </select>  
                          </th>
                          Entries</p>
                          
                                <th data-orderable="false"></th>
                                <th data-orderable="false"></th>
                                <th data-orderable="false"></th>
                                <th class="filtres">
                          <th class="searh_bar">
                                <?php if(isset($request['search'])): ?>
                                <input class="search_bar" type="text" placeholder="Search.." name="search" value="<?php echo $request['search']; ?>">
                                <?php else: ?>
                                <input class="search_bar" type="text" placeholder="Search.." name="search">
                                <?php endif; ?>
                                <button onchange="filtreresult()" class="search_button" type="submit"><i class="fa fa-search"></i></button>
                                <input type="hidden" id="page" name="page" >  
                              </th>
</tr>
                        <tr>
                        <th>id</th>
                        <th class="cu">Type/Action</th>
                        <th class="cu">Ac/Username</th>
                        <th class="cu">Variant/Passwd</th>
                        <th class="cu">Cat</th>
                        <th class="cu">Check</th>
                        </tr>
                        <tr>
                        
                        <?php $__currentLoopData = $airCraft; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $airCraf): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                        
                        <td><?php echo e($airCraf->id); ?></td>
                        <td><?php echo e($airCraf->fleetACCategory); ?></td>
                        <td><?php echo e($airCraf->Manufacturer); ?></td>
                        <td><?php echo e($airCraf->fleetAC_Type); ?></td>
                        <td><?php echo e($airCraf->priceCategory); ?></td>
                        <td><?php echo e($airCraf->checkTrial); ?></td>
                        </tr>
                        <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                        
                  </thead>
                  
                </table>
                <?php echo e(Form::close()); ?>  
                <div class="d-flex justify-content-center">
                        <?php echo e($airCraft->links('admin.pagination')); ?> 
                
                      </div>
              </div>    
              </div>
            </div>
        </div>
    </div>
    
</div>
</div>
</div> 

<script>

function filtreresult() {

    document.getElementById("myForm").submit();

    $.ajax({ 
        headers: {
            'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
        },
         url: "<?php echo e(route('aircraftview')); ?>",
         body: formData,
         type: 'post',
         success: function(result){
            console.log(result)
         }
        });
}
  </script>
<?php $__env->stopSection(); ?>

<?php echo $__env->make('admin.layouts.master', \Illuminate\Support\Arr::except(get_defined_vars(), array('__data', '__path')))->render(); ?>

==> prd_backup_23_03_23.zip: prd/storage/framework/views/1db2f5df2afa7f6a54304136284c012e70a4663f.php <==

<?php $__env->startSection('content'); ?>
<style>
  table{
  /* margin: 0 auto; */
  clear: both;
  border-collapse: collapse;
  /* table-layout: fixed;  */
  word-wrap:break-word; 
  display: inline-table;
} 
  </style>
<head>
  <meta name="csrf-token" content="<?php echo e(csrf_token()); ?>">
</head>
<div class="breadcrumb-area">
  <div class="container-fluid">
    <nav aria-label="breadcrumb">
      <ol class="breadcrumb">
        <li class="breadcrumb-item"><a href="#">Activity</a></li>
        </li>
      </ol>
    </nav>
  </div>
</div>

<div class="container-fluid">
  <div class="row">
    <div class="col-12">
      <div class="product-list--area bg-boxshadow">
        <div class="row">
          <div class="col-lg-12">
            <div class="ibox">
              <div class="ibox-content">
                <table id="my_table3" class="display table table-stripped toggle-arrow-tiny dataTable no-footer" data-page-size="15">
                  
                    <thead>
                        <tr>
                        <th>id</th>
                        <th class="cu">Aircraft Name</th>
                        </tr>
                        <tr>
                        <?php $__currentLoopData = $airCraft; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $airCraf): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>

                        <td><?php echo e($airCraf['id']); ?></td>
                        <td><?php echo e($airCraf['aircraft']); ?></td>
                        </tr>
                        <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                        
                  </thead>
                </table>
              </div>    
              </div>
            </div>
        </div>
    </div>
</div>
</div>
</div> 
<?php $__env->stopSection(); ?>

<?php echo $__env->make('admin.layouts.master', \Illuminate\Support\Arr::except(get_defined_vars(), array('__data', '__path')))->render(); ?>
